---
title: <span class="badge object-type-enum"></span> TooltipMode
---
# <span class="badge object-type-enum"></span> TooltipMode

## Definition

```python
class TooltipMode(enum.StrEnum):
    NONE = "none"
    DETAILS = "details"
```
